==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPivotDimensionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDetailDescriptionMetadata } from "./WebPivotDimensionDetailDescriptionMetadata";
import { WebPivotDimensionEventArgsDescription } from "./WebPivotDimensionEventArgsDescription";
/**
 * @hidden
 */
var WebPivotDimensionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionEventArgsDescriptionMetadata, _super);
    function WebPivotDimensionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionEventArgsDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionEventArgsDescriptionMetadata.a == null) {
            WebPivotDimensionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionEventArgsDescriptionMetadata.c(WebPivotDimensionEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPivotDimensionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPivotDimensionEventArgsDescriptionMetadata.a);
        WebPivotDimensionDetailDescriptionMetadata.d(a);
    };
    WebPivotDimensionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionEventArgs");
        a.item("Detail", "ExportedType:WebPivotDimensionDetail");
    };
    WebPivotDimensionEventArgsDescriptionMetadata.d = function (a) {
        WebPivotDimensionEventArgsDescriptionMetadata.b(a);
        a.aa("WebPivotDimensionEventArgs", function () { return new WebPivotDimensionEventArgsDescription(); });
        a.z("WebPivotDimensionEventArgs", WebPivotDimensionEventArgsDescriptionMetadata.a);
    };
    WebPivotDimensionEventArgsDescriptionMetadata.$t = markType(WebPivotDimensionEventArgsDescriptionMetadata, 'WebPivotDimensionEventArgsDescriptionMetadata');
    WebPivotDimensionEventArgsDescriptionMetadata.a = null;
    return WebPivotDimensionEventArgsDescriptionMetadata;
}(Base));
export { WebPivotDimensionEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPivotDimensionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDetailDescriptionMetadata } from "./WebPivotDimensionDetailDescriptionMetadata";
import { WebPivotDimensionEventArgsDescription } from "./WebPivotDimensionEventArgsDescription";
/**
 * @hidden
 */
var WebPivotDimensionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionEventArgsDescriptionMetadata, _super);
    function WebPivotDimensionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionEventArgsDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionEventArgsDescriptionMetadata.a == null) {
            WebPivotDimensionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionEventArgsDescriptionMetadata.c(WebPivotDimensionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPivotDimensionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPivotDimensionEventArgsDescriptionMetadata.a);
        WebPivotDimensionDetailDescriptionMetadata.d(a);
    };
    WebPivotDimensionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionEventArgs");
        a.item("Detail", "ExportedType:WebPivotDimensionDetail");
    };
    WebPivotDimensionEventArgsDescriptionMetadata.d = function (a) {
        WebPivotDimensionEventArgsDescriptionMetadata.b(a);
        a.ac("WebPivotDimensionEventArgs", function () { return new WebPivotDimensionEventArgsDescription(); });
        a.ab("WebPivotDimensionEventArgs", WebPivotDimensionEventArgsDescriptionMetadata.a);
    };
    WebPivotDimensionEventArgsDescriptionMetadata.$t = markType(WebPivotDimensionEventArgsDescriptionMetadata, 'WebPivotDimensionEventArgsDescriptionMetadata');
    WebPivotDimensionEventArgsDescriptionMetadata.a = null;
    return WebPivotDimensionEventArgsDescriptionMetadata;
}(Base));
export { WebPivotDimensionEventArgsDescriptionMetadata };
